@@ -11,7 +11,8 @@ test_that("Filtering an empty Task (#39)", {
   f$calculate(task)
   expect_numeric(f$scores, names = "unique", len = 0)
 
-  task = mlr_tasks$get("mtcars")$filter(character())
+  no_ids = task$row_ids[0]
+  task = mlr_tasks$get("mtcars")$filter(no_ids)
   f = mlr_filters$get("variance")
   f$calculate(task)
   expect_numeric(f$scores, names = "unique", len = length(task$feature_names))
